unit eprom;  {Zum Ansteuern des Eprom-Brenners fr den LPT-Bus}

{Wenn gerade nicht auf das Eprom zugegriffen wird, sind alle
Daten- und Adressleitungen hochohmig. Es liegt keine Programmier-
spannung an}

interface

procedure eprom_setup(slot:byte;zeit:byte);

function eprom_read(adresse:word):byte;

function eprom_write(adresse:word;wert:byte):boolean; {True, wenn Ok}

procedure eprom_readblock(von,bis:word;puffer:pointer);

function eprom_writeblock(von,bis:word;puffer:pointer):word; {Fehlerzahl}

implementation

{$ifdef windows}
  uses lpt_bus,windelay;
{$else}
  uses lpt_bus,crt;
{$endif}

type ptr=record
       ofs,seg:word;
     end;

var basis:byte;
    brennzeit:byte;

procedure incptr(var p:pointer);
  begin
    with ptr(p) do begin
      inc(ofs);
      while ofs>15 do begin
        inc(seg);
        dec(ofs,16);
      end;
    end;
  end;

procedure eprom_setup(slot:byte;zeit:byte);
  begin
    if slot>15 then
      runerror;
    basis:=slot shl 4;
    brennzeit:=zeit;
    bus_read(basis);
    bus_write(basis+3,$9B);
  end;

function eprom_read(adresse:word):byte;
  begin
    bus_write(basis+3,$90);
    bus_write(basis+1,lo(adresse));
    bus_write(basis+2,hi(adresse));
    eprom_read:=bus_read(basis);
    bus_write(basis+3,$9B);
  end;

function eprom_write(adresse:word;wert:byte):boolean;
  var b:byte;
  begin
    bus_write(basis+3,$80);
    bus_write(basis+1,lo(adresse));
    bus_write(basis+2,hi(adresse));
    delay(brennzeit);
    b:=bus_read(basis);
    bus_write(basis+3,$90);
    bus_write(basis+1,lo(adresse));
    bus_write(basis+2,hi(adresse));
    b:=bus_read(basis);
    eprom_write:=b=wert;
    bus_write(basis+3,$9B);
  end;


procedure eprom_readblock(von,bis:word;puffer:pointer);
  var w:word;
      p:pointer;
  begin
    if (von>bis) or (puffer=nil) then
      runerror;
    p:=puffer;
    for w:=von to bis do begin
      byte(p^):=eprom_read(w);
      incptr(p);
      {$ifdef windows}
        messageloop;
      {$endif}
    end;
  end;

function eprom_writeblock(von,bis:word;puffer:pointer):word;
  var w:word;
      p:pointer;
      fehler:word;
  begin
    if (von>bis) or (puffer=nil) then
      runerror;
    p:=puffer;
    fehler:=0;
    for w:=von to bis do begin
      if not eprom_write(w,byte(p^))
        then inc(fehler);
      incptr(p);
    end;
    eprom_writeblock:=fehler;
  end;

end.
